-- vim: ts=2 sw=2 ai et enc=utf8 fenc=utf8

local L = RaidChecklistStrings
local NAME = L["Raid Checklist"]
local CfgHandler = {}

function CfgHandler:GetVal (info)
    local varname = info[#info]
    return RaidChecklistDB.profile[varname]
end

function CfgHandler:SetVal (info, v)
    local varname = info[#info]
    RaidChecklistDB.profile[varname] = v
    if RaidChecklist.OnConfigChange then
      RaidChecklist.OnConfigChange ()
    end
end

local config = {
  type = 'group',
  handler = CfgHandler,
  get = "GetVal", set = "SetVal",
  args = {
    config = {
      type = 'group',
      name = L.CONFIG,
      args = {
        hdr = { type = 'description', name = NAME.." - by Anyia of HordeYakka (Jubei'Thos)", order = 1 },
        blank = { type = 'header', name = "", order = 2 },
        anchor_locked = {
          type = 'toggle', 
          name = L.ANCHORLOCKED,
          desc = L.ANCHORLOCKEDDESC,
          order = 50
        },
        show_anchor = {
          type = 'toggle',
          name = L.SHOWANCHOR,
          desc = L.SHOWANCHORDESC,
          order = 60
        },
        open_direction = {
          type = 'select',
          name = L.OPENDIRECTION,
          desc = L.OPENDIRECTIONDESC,
          values = { DOWNRIGHT = L.DOWNRIGHT, DOWNLEFT = L.DOWNLEFT, UPRIGHT = L.UPRIGHT, UPLEFT = L.UPLEFT },
          order = 100
        },
        filler = { type = 'description', name = '', order = 200 },
        reset_anchor = {
          type = 'execute',
          name = L.RESETANCHOR,
          desc = L.RESETANCHORDESC,
          func = function ()
            RaidChecklist.button:ClearAllPoints ()
            RaidChecklist.button:SetPoint ("CENTER", 0, 0)
            RaidChecklistDB.profile.xoffs = 0
            RaidChecklistDB.profile.yoffs = 0
          end,
          order = 300
        }
      }
    }
  }
}

local defaults = {
  profile = {
    show_anchor = true,
    anchor_locked = false,
    open_direction = "DOWNRIGHT",
    anchorpoint = "CENTER",
    relpoint = "CENTER",
    x = 0,
    y = 0
  }
}
RaidChecklistDB = defaults
-- Note: if I need to add more config vars later, I need to explicitly copy defaults into the existing RaidChecklistDB after it has been loaded

LibStub ("AceConfigRegistry-3.0"):RegisterOptionsTable (NAME, config)
RaidChecklist.cfgdlg = LibStub ("AceConfigDialog-3.0")
RaidChecklist.cfgdlg:AddToBlizOptions (NAME, nil, nil, "config")

